@@ -443,11 +443,11 @@ class HttpTest(unittest.TestCase):
         self.assertEqual("302", response['status'])
         self.assertTrue(content.startswith("This is content"))
 
-    def testGet302ViaHttps(self):
-        # Google always redirects to http://google.com
-        (response, content) = self.http.request("https://www.google.com", "GET")
+    def testGet301ViaHttps(self):
+        # Google always redirects to https://www.google.com
+        (response, content) = self.http.request("https://code.google.com/apis/", "GET")
         self.assertEqual(200, response.status)
-        self.assertEqual(302, response.previous.status)
+        self.assertEqual(301, response.previous.status)
 
     def testGetViaHttps(self):
         # Test that we can handle HTTPS
@@ -482,6 +482,14 @@ class HttpTest(unittest.TestCase):
             self.assertRaises(httplib2.SSLHandshakeError,
                     http.request, "https://www.google.com/", "GET")
 
+    def testSslCertValidationDoubleDots(self):
+        if sys.version_info >= (2, 6):
+            # Test that we get match a double dot cert
+            try:
+              self.http.request("https://1.www.appspot.com/", "GET")
+            except httplib2.CertificateHostnameMismatch:
+              self.fail('cert with *.*.appspot.com should not raise an exception.')
+
     def testSslHostnameValidation(self):
         if sys.version_info >= (2, 6):
             # The SSL server at google.com:443 returns a certificate for
@@ -1470,6 +1478,21 @@ class HttpPrivateTest(unittest.TestCase):
         working_request = 'authorization: Digest username="joe", realm="myrealm", nonce="Ygk86AsKBAA=3516200d37f9a3230352fde99977bd6d472d4306", uri="/projects/httplib2/test/digest/", algorithm=MD5, response="97ed129401f7cdc60e5db58a80f3ea8b", qop=auth, nc=00000001, cnonce="33033375ec278a46"'
         self.assertEqual(our_request, working_request)
 
+    def testDigestObjectWithOpaque(self):
+        credentials = ('joe', 'password')
+        host = None
+        request_uri = '/projects/httplib2/test/digest/'
+        headers = {}
+        response = {
+            'www-authenticate': 'Digest realm="myrealm", nonce="Ygk86AsKBAA=3516200d37f9a3230352fde99977bd6d472d4306", algorithm=MD5, qop="auth", opaque="atestopaque"'
+        }
+        content = ""
+
+        d = httplib2.DigestAuthentication(credentials, host, request_uri, headers, response, content, None)
+        d.request("GET", request_uri, headers, content, cnonce="33033375ec278a46")
+        our_request = "authorization: %s" % headers['authorization']
+        working_request = 'authorization: Digest username="joe", realm="myrealm", nonce="Ygk86AsKBAA=3516200d37f9a3230352fde99977bd6d472d4306", uri="/projects/httplib2/test/digest/", algorithm=MD5, response="97ed129401f7cdc60e5db58a80f3ea8b", qop=auth, nc=00000001, cnonce="33033375ec278a46", opaque="atestopaque"'
+        self.assertEqual(our_request, working_request)
 
     def testDigestObjectStale(self):
         credentials = ('joe', 'password')
